==> openshift-model-hive-5.12.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterClaimBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterClaimBuilder extends io.fabric8.openshift.api.model.hive.v1.ClusterClaimFluentImpl<io.fabric8.openshift.api.model.hive.v1.ClusterClaimBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.ClusterClaim,io.fabric8.openshift.api.model.hive.v1.ClusterClaimBuilder>{
  public ClusterClaimBuilder() {
    this(false);
  }
  public ClusterClaimBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterClaim(), validationEnabled);
  }
  public ClusterClaimBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterClaimFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterClaimBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterClaimFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterClaim(), validationEnabled);
  }
  public ClusterClaimBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterClaimFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.ClusterClaim instance) {
    this(fluent, instance, false);
  }
  public ClusterClaimBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterClaimFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.ClusterClaim instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterClaimBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterClaim instance) {
    this(instance,false);
  }
  public ClusterClaimBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterClaim instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.ClusterClaimFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.ClusterClaim build() {
    ClusterClaim buildable = new ClusterClaim(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterClaimBuilder that = (ClusterClaimBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.4.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterClaimBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterClaimBuilder extends ClusterClaimFluentImpl<ClusterClaimBuilder> implements VisitableBuilder<ClusterClaim,ClusterClaimBuilder>{
  public ClusterClaimBuilder() {
    this(false);
  }
  public ClusterClaimBuilder(Boolean validationEnabled) {
    this(new ClusterClaim(), validationEnabled);
  }
  public ClusterClaimBuilder(ClusterClaimFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterClaimBuilder(ClusterClaimFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterClaim(), validationEnabled);
  }
  public ClusterClaimBuilder(ClusterClaimFluent<?> fluent,ClusterClaim instance) {
    this(fluent, instance, false);
  }
  public ClusterClaimBuilder(ClusterClaimFluent<?> fluent,ClusterClaim instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterClaimBuilder(ClusterClaim instance) {
    this(instance,false);
  }
  public ClusterClaimBuilder(ClusterClaim instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ClusterClaimFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterClaim build() {
    ClusterClaim buildable = new ClusterClaim(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
